# Datalake bundle

This bundle allows you to easily create and manage datalake(house) based on the [Daipe Framework](https://www.daipe.ai).  

## Resources

* [Documentation](https://docs.daipe.ai/data-pipelines-workflow/managing-datalake/)
